
# polympiads/statelessauth

This is a project meant to be used for general purpose data or authentication stored on the client side.

# Documentation

Documentation for the project is accessible at `https://polympiads.github.io/telemetry`
